@@ -303,7 +303,7 @@ clustIndex <- function( y, x, index="all" )
 ###needed measures 
     ##withins <- withinss1(x, centers, cluster)
     ## varwithins <- varwithinss(x, clres$centers, clres$cluster)
-    zgss <- gss(x,clres$size, clres$withins)
+    zgss <- gss(x,clres$size, clres$withinss)
     ## zvargss <- vargss(x, clres$size,varwithins)
     zttw <- ttww(x, clres$size, clres$cluster)
     ## minmaxd <-maxmindist(clres$size,distdata)
@@ -332,12 +332,12 @@ clustIndex <- function( y, x, index="all" )
           {
             distdata <- count(x)
             minmaxd <- maxmindist(clres$size,distdata)
-            vecallindex[2] <- cindex(clres$withins, minmaxd, clres$size)
+            vecallindex[2] <- cindex(clres$withinss, minmaxd, clres$size)
           }
         else  vecallindex[2] <- NA
       }
     if (any(index==3) || (index==16))
-      vecallindex[3] <- db(clres$withins, clres$centers, clres$cluster)
+      vecallindex[3] <- db(clres$withinss, clres$centers, clres$cluster)
     if (any(index==4) || (index==16))
       vecallindex[4] <- hartigan(zgss)
     if (any(index==5) || (index==16))
@@ -351,7 +351,7 @@ clustIndex <- function( y, x, index="all" )
     if (any(index==7) || (index==16))
        vecallindex[7] <- marriot(zttw,clres$size)
     if (any(index==8) || (index==16))
-       vecallindex[8] <- ball(clres$withins, clres$size)
+       vecallindex[8] <- ball(clres$withinss, clres$size)
     if (any(index==9) || (index==16))
        vecallindex[9] <- tracecovw(zttw)
     if (any(index==10) || (index==16))
